package com.fs.company.service;

import java.util.List;
import java.util.Map;

import com.fs.company.domain.CompanyTagUser;
import com.fs.company.vo.CompanyTagUserVO;
import com.fs.store.param.h5.TagListParam;
import com.fs.store.vo.h5.CompanyUserTagListVO;

import javax.validation.constraints.NotNull;

/**
 * companyService接口
 *
 * @author fs
 * @date 2025-04-02
 */
public interface ICompanyTagUserService
{
    /**
     * 查询company
     *
     * @param id companyID
     * @return company
     */
    public CompanyTagUser selectCompanyTagUserById(Long id);

    /**
     * 查询company列表
     *
     * @param companyTagUser company
     * @return company集合
     */
    public List<CompanyTagUser> selectCompanyTagUserList(CompanyTagUser companyTagUser);

    /**
     * 新增company
     *
     * @param companyTagUser company
     * @return 结果
     */
    public int insertCompanyTagUser(CompanyTagUser companyTagUser);

    /**
     * 修改company
     *
     * @param companyTagUser company
     * @return 结果
     */
    public int updateCompanyTagUser(CompanyTagUser companyTagUser);

    /**
     * 批量删除company
     *
     * @param ids 需要删除的companyID
     * @return 结果
     */
    public int deleteCompanyTagUserByIds(Long[] ids);

    /**
     * 删除company信息
     *
     * @param id companyID
     * @return 结果
     */
    public int deleteCompanyTagUserById(Long id);

    /**
     * 标签分页列表
     * @param param 分页参数
     * @return
     */
    List<CompanyUserTagListVO> getTagList(TagListParam param);

    /**
     * 根据条件查询标签下用户
     * @param params    条件
     * @return  list
     */
    List<CompanyTagUserVO> selectUserListByMap(Map<String, Object> params);

    /**
     * 修改用户标签
     * @param fsUserId 用户ID
     * @param tagIds   标签ID集合
     */
    void changeUserTags(Long fsUserId, List<Long> tagIds);
}
